<?php

// Make sure we don't expose any info if called directly
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Keremiya panel get option
 */
function xtcore_get_option( $name ) {
	$get_options = get_option( sanitize_key(theme_name) . '_options' );
	
	if( !empty( $get_options[$name] ))
		return $get_options[$name];
		
	return false ;
}

/**
 *  Parse Url
 */
function xtcore_parse_url($input) {
    // If scheme not included, prepend it
    if (!preg_match('#^http(s)?://#', $input)) {
        $input = 'http://' . $input;
    }

    $urlParts = parse_url($input);

    // remove www
    $domain = preg_replace('/^www\./', '', $urlParts['host']);

    return $domain;
}

/**
 *  Clear output
 */
function xtcore_clear($d) {
    return htmlspecialchars( trim( $d ) );
}

// Clean post data
function xtcore_clean($content, $allow="") {
    return htmlspecialchars( strip_tags( trim( $content ), $allow ) );
}

// Clean array data
function xtcore_clean_array(&$value) {
    return htmlspecialchars( strip_tags( trim( $value ) ) );
}

/**
 *  Display Message
 */
function xtcore_display_message( $message = false ) {
    if( is_wp_error( $message ) ) {
        return '<div class="message error">' . $message->get_error_message() . '</div>';
    }

    return false;
}

/**
 *  Display Error
 */
function xtcore_display_error($message) {
    if( $message )
        return '<div class="message error">' . $message . '</div>';

    return false;
}

/**
 * Get site url 
 */
function xtcore_plugin_site_url() {
    return 'https://www.xxxthemes.com/';
}

/**
 * Get api url 
 */
function xtcore_api_url( $endpoint = 'license' ) {
	return xtcore_plugin_site_url() . '/api/' . $endpoint;
}

/**
 * Connect Api 
 */
function xtcore_remote($api_url) {

    $args     = array(
        'timeout'   => 10,
        'sslverify' => false,
    );
    $response = wp_remote_get( $api_url, $args );

    if ( is_wp_error( $response ) ) {
        $error_message = $response->get_error_message();
        $data['response'] = 'true';
        $data['status'] = 100;
        $data['message'] = $error_message;
        $data = json_encode($data);
    } else {
        if($response['response']['code'] == 200) {
            $data = $response['body'];
        }
    }

    return json_decode($data);
}

/**
 * Connect License API
 */
add_action('wp_ajax_nopriv_xtcore_license_form_action', 'xtcore_ajax_license_form_action');
add_action('wp_ajax_xtcore_license_form_action', 'xtcore_ajax_license_form_action');
function xtcore_ajax_license_form_action() {

    if ( ! current_user_can( 'install_themes' ) ) {
        $error = xtcore_display_error( __('You do not have sufficient permissions.', 'xxxThemes') );
        die( $error );
    }

	$key = $_POST['license_key'];

    // Güvenlik kontrolü
    $nonce = $_POST['nonce'];

    if ( ! wp_verify_nonce( $nonce, 'xtcore_ajax_license_form_action_nonce' ) ) { 
        $error = xtcore_display_error( __('There seems to be a security error, please try again later.', 'xxxThemes') );
        die( $error );
    }

    $api_data = array(
    	'license_key' => $key,
    	'license_type' => 'plugin_activation'
    );
    $api_url = add_query_arg($api_data, xtcore_api_url());
    $result = xtcore_remote($api_url);

	if( $result->response == 'true' ) {
		if( $result->status == 200 ) {
			/* Start WP lion Session */
			update_option('plugin_product_list', $result->data);
            update_option('plugin_connect_list', '');
			wplion_session_start($key);
		}

		echo $result->message;
	}
    exit;
}

// Add a new interval of 180 seconds
// See http://codex.wordpress.org/Plugin_API/Filter_Reference/cron_schedules
add_filter( 'cron_schedules', 'xtcore_api_update_products' );
function xtcore_api_update_products( $schedules ) {
    $schedules['every_daily'] = array(
        'interval'  => 86400,
        'display'   => __( 'Every Daily' )
    );
    return $schedules;
}

// Schedule an action if it's not already scheduled
if ( ! wp_next_scheduled( 'xtcore_api_update_products' ) ) {
    wp_schedule_event( time(), 'every_daily', 'xtcore_api_update_products' );
}

// Hook into that action that'll fire every three minutes
add_action( 'xtcore_api_update_products', 'xtcore_api_update_products_func' );
function xtcore_api_update_products_func() {

    if( empty(xtcore_get_wplion_key()) )
        return false;

    $api_data = array(
        'license_key' => xtcore_get_wplion_key(),
        'license_type' => 'plugin_activation'
    );
    $api_url = add_query_arg($api_data, xtcore_api_url());
    $result = xtcore_remote($api_url);

    if( $result->response == 'true' ) {
        if( $result->status == 200 ) {
            /* Start WP lion Session */
            update_option('plugin_product_list', $result->data);
        }
    }
}

/**
 * Get product list
 */
function xtcore_get_product_list() {
	return get_option('plugin_product_list') ?: array();
}
/**
 * Get connect list 
 */
function xtcore_get_connect_list() {
    return get_option('plugin_connect_list') ?: array();
}

/**
 * Session Start
 */
function wplion_session_start($key) {
	update_option('wplion_session', array('checker' => 40, 'key' => $key));
}

/**
 * Session Status
 */
function xtcore_wplion_status() {
	$status = get_option('wplion_session');

	if( ! empty( $status ) && isset( $status['checker'] ) && $status['checker'] == 40 && isset( $status['key'] ) && !empty($status['key']) ) {
		return true;
	}

	return false;
}
/**
 * Get Key
 */
function xtcore_get_wplion_key() {
    $status = get_option('wplion_session');

    if( ! empty( $status ) && isset( $status['checker'] ) && $status['checker'] == 40 && isset( $status['key'] ) && !empty($status['key']) ) {
        return $status['key'];
    }

    return false;
}

/**
 * Connect Theme API
 */
add_action('wp_ajax_nopriv_xtcore_connect_theme_action', 'xtcore_ajax_connect_theme_action');
add_action('wp_ajax_xtcore_connect_theme_action', 'xtcore_ajax_connect_theme_action');
function xtcore_ajax_connect_theme_action() {

    if ( ! current_user_can( 'install_themes' ) ) {
        $error = xtcore_display_error( __('You do not have sufficient permissions.', 'xxxThemes') );
        die( $error );
    }

    $theme_name = $_POST['theme_name'];

    // Güvenlik kontrolü
    $nonce = $_POST['nonce'];

    if ( ! wp_verify_nonce( $nonce, 'xtcore_ajax_connect_theme_action_nonce' ) ) { 
        $error = xtcore_display_error( __('There seems to be a security error, please try again later.', 'xxxThemes') );
        die( $error );
    }

    $api_data = array(
        'license_key' => xtcore_get_wplion_key(),
        'product_name' => $theme_name,
        'domain'    => xtcore_parse_url( get_bloginfo('url') ),
    );

    $api_url = add_query_arg($api_data, xtcore_api_url());
    $result = xtcore_remote($api_url);

    if( $result->response == 'true' ) {
        if( $result->status == 200 ) {
            /* Start WP lion Session */

            $sanitize_theme_name = sanitize_key($theme_name);
            $connected_data = xtcore_get_connect_list();
            $connected_data[$sanitize_theme_name]['status'] = 'connected';
            $connected_data[$sanitize_theme_name]['time'] = current_time('timestamp');

            update_option('plugin_connect_list', $connected_data);
        }

        echo $result->message;
    }
    exit;
}

/**
 * Ajax Install Product
 */
add_action('wp_ajax_nopriv_xtcore_install_product_action', 'xtcore_install_product');
add_action('wp_ajax_xtcore_install_product_action', 'xtcore_install_product');
function xtcore_install_product() {

    if ( ! current_user_can( 'install_themes' ) ) {
        $error = xtcore_display_error( __('You do not have sufficient permissions.', 'xxxThemes') );
        die( $error );
    }

    // Güvenlik kontrolü
    $nonce = $_POST['nonce'];

    if ( ! wp_verify_nonce( $nonce, 'xtcore_ajax_connect_theme_action_nonce' ) ) { 
        $error = xtcore_display_error( __('There seems to be a security error, please try again later.', 'xxxThemes') );
        die( $error );
    }

    if ( ! isset( $_POST['method'], $_POST['type'], $_POST['product'] ) ) {
        $error = xtcore_display_error( __('There seems to be a error, please try again later.', 'xxxThemes') );
        die( $error );
    }

    $method              = sanitize_text_field( wp_unslash( $_POST['method'] ) );
    $product_type        = sanitize_text_field( wp_unslash( $_POST['type'] ) );
    $product_name        = sanitize_text_field( wp_unslash( $_POST['product'] ) );
    $product_slug        = sanitize_key( $product_name );

    $api_data            = array(
        'license_key'   => xtcore_get_wplion_key(),
        'product_name'  => $product_name,
        'api_connect'   => 1
    );
    $product_zip         = add_query_arg($api_data, xtcore_api_url('download'));

    $product   = array(
        'file_path'   => $product_slug . '/' . $product_slug . '.php',
        'package'     => $product_zip,
        'slug'        => $product_slug,
    );

    require_once( XXXTHEMES__PLUGIN_DIR . 'inc/installer.php' );

    $installer = new XTCORE_Product_Uploader();
    $output    = $installer->upload_product( $product_type, $method, $product );

    wp_send_json( $output );
    die();
}

/**
 * AJAX Activate theme 
 */
add_action('wp_ajax_nopriv_xtcore_toggle_theme_action', 'xtcore_toggle_theme');
add_action('wp_ajax_xtcore_toggle_theme_action', 'xtcore_toggle_theme');
function xtcore_toggle_theme() {

    if ( ! current_user_can( 'install_themes' ) ) {
        $error = xtcore_display_error( __('You do not have sufficient permissions.', 'xxxThemes') );
        die( $error );
    }

    // Güvenlik kontrolü
    $nonce = $_POST['nonce'];

    if ( ! wp_verify_nonce( $nonce, 'xtcore_ajax_connect_theme_action_nonce' ) ) { 
        $error = xtcore_display_error( __('There seems to be a security error, please try again later.', 'xxxThemes') );
        die( $error );
    }

    if ( ! isset( $_POST['type'], $_POST['product'] ) ) {
        $error = xtcore_display_error( __('There seems to be a error, please try again later.', 'xxxThemes') );
        die( $error );
    }

    switch_theme( sanitize_key( wp_unslash( $_POST['product'] ) ) );

    $output = 'activated';

    echo $output;
    die();
}


function xtcore_check_plugin_version() {

    $products_list = xtcore_get_product_list();

    if( empty( $products_list ) )
        return false;

    if( empty($products_list->plugin->download_url) || empty( $products_list->plugin->version ) )
        return false;

    $current_page = isset( $_REQUEST['page'] ) ? $_REQUEST['page'] : '';
    $dashboard_id = sanitize_title(XXXTHEMES_NAME) . '_dashboard';
    $panel_id = sanitize_title(XXXTHEMES_NAME) . '_panel';

    if( $current_page == $dashboard_id || $current_page == $panel_id ) {
    
        if( ! version_compare(XXXTHEMES_VERSION, $products_list->plugin->version, '>=') ) {
            ?>
            <div class="update-message notice inline notice-warning notice-alt">
                <p><?php printf(__('There is a new version of %1$s available.'), XXXTHEMES_NAME . ' Core'); ?>
                    <a href="javascript:;" class="update-xtcore">
                        <span class="text"><?php _e('Update now'); ?></span>
                    </a>
                </p>
            </div>
            <?php
        }
    }
}
add_action('admin_notices', 'xtcore_check_plugin_version');

/**
 * Ajax Install Product
 */
add_action('wp_ajax_nopriv_xtcore_update_core_action', 'xtcore_update_core');
add_action('wp_ajax_xtcore_update_core_action', 'xtcore_update_core');
function xtcore_update_core() {

    if ( ! current_user_can( 'install_plugins' ) ) {
        $error = xtcore_display_error( __('You do not have sufficient permissions.', 'xxxThemes') );
        die( $error );
    }

    // Güvenlik kontrolü
    $nonce = $_POST['nonce'];

    if ( ! wp_verify_nonce( $nonce, 'xtcore_ajax_connect_theme_action_nonce' ) ) { 
        $error = xtcore_display_error( __('There seems to be a security error, please try again later.', 'xxxThemes') );
        die( $error );
    }


    $products_list = xtcore_get_product_list();

    if( empty( $products_list ) ){
        $error = xtcore_display_error( __('Products list not found.', 'xxxThemes') );
        die( $error );
    }

    if( empty($products_list->plugin->download_url) || empty( $products_list->plugin->version ) ){
        $error = xtcore_display_error( __('xxxThemes core download url not found.', 'xxxThemes') );
        die( $error );
    }

    $method              = 'install';
    $product_type        = 'plugin';
    $product_slug        = 'xxxthemes-core';
    $product_zip         = $products_list->plugin->download_url;

    $product   = array(
        'file_path'   => $product_slug . '/' . $product_slug . '.php',
        'package'     => $product_zip,
        'slug'        => $product_slug,
    );

    require_once( XXXTHEMES__PLUGIN_DIR . 'inc/installer.php' );

    $installer = new XTCORE_Product_Uploader();
    $output    = $installer->upload_product( $product_type, $method, $product );

    wp_send_json( $output );
    die();
}