<?php
/**
 * Class installer
 *
 * @package CORE\Admin\Classes
 */

// Make sure we don't expose any info if called directly
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Installer Class
 *
 * @since 1.0.0
 */
class XTCORE_Product_Uploader {

	private $method;
	private $product;
	private $type;

	public function upload_product( $type, $method, $product ) {
		$this->product = $product;
		$this->method  = $method;
		$this->type    = $type;
		$response      = false;

		switch ( $type ) {
			case 'theme':
				// if user cannot install themes we die.
				if ( ! current_user_can( 'install_themes' ) ) {
					return __( 'You do not have sufficient permissions to install themes for this site.' );
				}
				$response = self::install_theme();
				break;

			case 'plugin':
				if ( ! current_user_can( 'install_plugins' ) ) {
					return __( 'You do not have sufficient permissions to install themes for this site.' );
				}
				$response = self::install_plugin();
				break;

			default:
				break;
		}
		return $response;
	}

	private function install_theme() {
		require_once ABSPATH . 'wp-admin/includes/admin.php';
		$upgrader = new Theme_Upgrader( new Theme_Quiet_Skin() );
		switch ( $this->method ) {
			case 'install':
				ob_start();
				$results = $upgrader->install( $this->product['package'], array('overwrite_package' => true) );
				$data    = ob_get_contents();
				ob_clean();
				break;
			case 'upgrade':
				ob_start();
				$results = $upgrader->upgrade( $this->product['slug'] );
				$data    = ob_get_contents();
				ob_clean();
				break;
			default:
				return false;
		}
		if ( ! $results ) {
			return $data;
		} else {
			return true;
		}
	}

	private function install_plugin() {
		require_once ABSPATH . 'wp-admin/includes/admin.php';
		$upgrader = new Plugin_Upgrader( new Plugin_Quiet_Skin() );
		switch ( $this->method ) {
			case 'install':
				ob_start();
				$results = $upgrader->install( $this->product['package'] );
				$data    = ob_get_contents();
				ob_clean();
				break;
			case 'upgrade':
				ob_start();
				$results = $upgrader->bulk_upgrade( array( $this->product['file_path'] ) );
				$data    = ob_get_contents();
				ob_clean();
				break;
			default:
				return false;
		}
		if ( ! $results ) {
			return $data;
		} else {
			return true;
		}
	}

	private function cleanup( $file ) {
		if ( file_exists( $file ) ) :
			unlink( $file );
		endif;
	}
}

require_once ABSPATH . 'wp-admin/includes/class-wp-upgrader.php';
class Plugin_Quiet_Skin extends Plugin_Installer_Skin {
	public function feedback( $string, ...$args ) {
		// just keep it quiet.
	}
}

class Theme_Quiet_Skin extends Theme_Installer_Skin {
	public function feedback( $string, ...$args ) {
		// just keep it quiet.
	}
}