<?php
// Make sure we don't expose any info if called directly
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

function plugin_options() {
	$reconnect = isset($_GET['reconnect']) ? true : false;
?>
<div class="plugin-wrap">
<div class="plugin-version"><?php echo XXXTHEMES_NAME; ?> <?php echo XXXTHEMES_VERSION; ?></div>
<?php if( ! xtcore_wplion_status() || $reconnect ) { ?>

<div class="activation-form">
	<h1><?php _e('License Activation'); ?></h1>
	<div class="activation-input">
		<span class="activation-secure-icon"><span class="dashicons dashicons-unlock"></span></span>
		<input type="text" id="plugin_activation_license_key" name="plugin_activation_license_key" placeholder="<?php esc_attr_e('Please paste your license key'); ?>">
		<?php wp_nonce_field( 'xtcore_ajax_license_form_action_nonce', 'xtcore_license_form_action_nonce' ); ?>
		<button class="button button-primary plugin_activation_submit"><?php _e('Activate'); ?></button>
	</div>
	<p class="plugin-message"><?php printf(__('If you do not have a license key, go to your %1$s account to get your license key.'), XXXTHEMES_SITE_NAME); ?></p>

	<div class="plugin-account-message">
		<p><?php printf(__('You dont have a %1$s license yet?'), XXXTHEMES_SITE_NAME); ?></p>
		<a href="<?php echo xtcore_plugin_site_url(); ?>/getting-started/" class="button button-primary" target="_blank"><?php _e('Getting Started'); ?></a>
	</div>
</div>

<?php } else { ?>

<div class="activation-form">
	<h1><?php printf(__('Your %1$s License Key'), XXXTHEMES_SITE_NAME); ?></h1>
	<div class="activation-input">
		<input type="password" id="plugin_license_key" name="plugin_license_key" value="************************" readOnly>
		<span class="activation-secure-icon yes"><span class="dashicons dashicons-yes"></span></span>
	</div>
	<p class="plugin-message"><?php _e('Your License key is valid. Just only it is hidden.'); ?></p>
</div>

<?php

	$themes = wp_get_themes();
	$active_theme = wp_get_theme();
	$products_list = xtcore_get_product_list();
	$connect_list = xtcore_get_connect_list();

	if( ! empty( $products_list->items ) ) {
		?>
		<div id="products-list">
			<h2><?php _e('Themes'); ?></h2>
			<div class="row">
				<?php 
					foreach($products_list->items as $key => $data ):
						if( $data->product_type != 'theme' )
							continue;

					$connected = false;
					$installed = false;
					$is_active = false;
					$current_theme = false;
					$sanitize_theme_name = sanitize_key($data->product_name);

					if( ! empty($connect_list) && isset( $connect_list[$sanitize_theme_name] ) ) {
						$connected = true;
					}

					if( isset( $themes[$sanitize_theme_name] ) ) {
						$installed = true;

						$current_theme = wp_get_theme($sanitize_theme_name);
					}

					if( sanitize_key($active_theme->Name) === $sanitize_theme_name ) {
						$is_active = true;
					}
				?>
				<div class="col-4">
					<div id="product-<?php echo $key; ?>" class="products-item">

						<div class="image"><img src="<?php echo $data->product_image; ?>"></div>

						<div class="title"><?php echo $data->product_name; ?></div>

						<div class="install">
							<?php echo( $installed ? $current_theme->Version : __('Not installed') ); ?>
						</div>

						<div class="alt-title"><?php echo $data->product_alt_title; ?> - <a href="<?php echo $data->product_url; ?>" target="_blank"><?php _e('Learn More'); ?></a></div>
						<div class="connect-area">
							<?php if( $connected ) { ?>

								<?php if( $installed ) { ?>
									<?php if( $is_active ) { ?>
										<span class="text"><?php _e('Active theme'); ?></span>
										
										<?php if( ! version_compare($current_theme->Version, $data->product_version, '>=') ) { ?>
											<div class="update">
											<?php printf( __('New version available. (v%1$s)'), $data->product_version ); ?>
											<a href="javascript:;" class="install-item button" data-method="install" data-type="theme" data-product="<?php echo $data->product_name; ?>">
												<span class="dashicons dashicons-admin-generic"></span>
												<span class="text"><?php _e('Update now'); ?></span>
											</a>
											</div>
										<?php } ?>
										
									<?php } else { ?>
										<a href="javascript:;" class="activated-item button" data-type="theme" data-product="<?php echo $data->product_name; ?>">
											<span class="dashicons dashicons-admin-generic"></span>
											<span class="text"><?php _e('Activate'); ?></span>
										</a>
									<?php }; ?>
								<?php } else { ?>
									<a href="javascript:;" class="install-item button button-primary" data-method="install" data-type="theme" data-product="<?php echo $data->product_name; ?>">
										<span class="dashicons dashicons-download"></span>
										<span class="text"><?php _e('Install now'); ?></span>
									</a>
								<?php }; ?>

							<?php } else { ?>
								<div class="connect-step-1">
									<a href="javascript:;" class="connect-next button button-primary"><span class="dashicons dashicons-admin-generic"></span><?php _e('Connect'); ?></a>
								</div>
								<div class="connect-step-2">
									<div class="connect-text"><?php printf( __('Connect <b>%1$s</b> on <span>%2$s</span>'), $data->product_name, xtcore_parse_url( get_bloginfo('url') ) ); ?></div>
									<a href="javascript:;" class="connect-cancel button"><?php _e('Cancel'); ?></a>
									<a href="javascript:;" class="connect-now button button-primary">
										<span class="dashicons dashicons-admin-generic"></span>
										<span class="text"><?php _e('Connect Now'); ?></span>
									</a>
								</div>
							<?php } ?>
						</div>
					</div>
				</div>
				<?php endforeach; ?>
			</div>
			<?php wp_nonce_field( 'xtcore_ajax_connect_theme_action_nonce', 'xtcore_connect_theme_action_nonce' ); ?>
		</div>
		<?php
	}
?>

<?php }; ?>

</div>
<?php
	plugin_footer_items();
}

function plugin_footer_items() {
	?>
	<div id="plugin-popup" class="modal">
		<div class="modal-inner">
			<div class="modal-close"><span class="dashicons dashicons-no"></span></div>
			<div class="modal-inner-con"></div>
		</div>
		<div class="modal-bg"></div>
	</div>
	<?php
}

?>